"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generateSuccessAction = exports.generateActionReadList = exports.generateAction = void 0;

var _action = require("./utils/action");

/**
 * Generate an action to dispatch
 * @param {String} method - HTTP method
 * @param {String} resource - Resource type (eg: monster/bear)
 * @param {Object} params - all payload params (eg: attributes, meta...)
 * @param {String} params.url - endpoint on which request resource
 * @param {String} params.type - type of the requested ressource
 */
const generateAction = (method, resource, params = {}) => {
  if (!('resourceUri' in params)) {
    throw new Error('All actions must implement url param');
  }

  return {
    type: (0, _action.generateActionTypeRequest)(method, resource),
    requestData: {
      type: resource
    },
    ...params
  };
};
/**
* Generate a read list action to dispatch
* @param {String} resource - Resource type (eg: monster/bear)
* @param {Object} params - all payload params (eg: attributes, meta...)
* @param {String} params.url - endpoint on which request resource
* @param {String} params.type - type of the requested ressource
*/


exports.generateAction = generateAction;

const generateActionReadList = (resource, params = {}) => generateAction('read_list', resource, params);
/**
 * Generate an action to dispatch
 * @param {String} method - HTTP method
 * @param {String} resource - Resource type (eg: monster/bear)
 * @param {Object} params - all payload params (eg: attributes, meta...)
 * @param {String} params.url - endpoint on which request resource
 * @param {String} params.type - type of the requested ressource
 */


exports.generateActionReadList = generateActionReadList;

const generateSuccessAction = (method, resource, payload) => ({
  type: (0, _action.generateActionTypeSuccess)(method, resource),
  payload
});

exports.generateSuccessAction = generateSuccessAction;