"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generateActionTypeError = exports.generateActionTypeSuccess = exports.generateActionTypeRequest = exports.generateActionType = void 0;

/**
 * Generate an action string for run request
 * All theses kind of actions will be catched by saga to perform request
 * @param {String} method - Will be uppercased for the action
 * @param {String} resource - Will be underscored and uppercased
 * @example generateActionType('update', 'blog/article') =
 *  '@@api/UPDATE_RESOURCE_BLOG_ARTICLE';
 */
const generateActionType = (method, resource) => `@@api/${method.toUpperCase()}_RESOURCE_${resource.replace('/', '_').toUpperCase()}`;
/**
 * Action type dispatched on request perform with success
 * @param {String} method - Will be uppercased for the action
 * @param {String} resource - Will be underscored and uppercased
 * @example generateActionType('update', 'blog/article') =
 *  '@@api/UPDATE_RESOURCE_BLOG_ARTICLE_SUCCESS';
 */


exports.generateActionType = generateActionType;

const generateActionTypeRequest = (method, resource) => `${generateActionType(method, resource)}_REQUEST`;
/**
 * Action type dispatched on request perform with success
 * @param {String} method - Will be uppercased for the action
 * @param {String} resource - Will be underscored and uppercased
 * @example generateActionType('update', 'blog/article') =
 *  '@@api/UPDATE_RESOURCE_BLOG_ARTICLE_SUCCESS';
 */


exports.generateActionTypeRequest = generateActionTypeRequest;

const generateActionTypeSuccess = (method, resource) => `${generateActionType(method, resource)}_SUCCESS`;
/**
 *
 * @param {String} method - Will be uppercased for the action
 * @param {String} resource - Will be underscored and uppercased
 * @example generateActionType('update', 'blog/article') =
 *  '@@api/UPDATE_RESOURCE_BLOG_ARTICLE_ERROR';
 */


exports.generateActionTypeSuccess = generateActionTypeSuccess;

const generateActionTypeError = (method, resource) => `${generateActionType(method, resource)}_ERROR`;

exports.generateActionTypeError = generateActionTypeError;